referrerpolicy=no-referrer-when-downgrade

set_budget_allocation

Function set_budget_allocation 

pub fn set_budget_allocation<T: Config>(new_allocations: BudgetAllocationMap)
Set the budget allocation map.

Each key must match a registered BudgetRecipient. The sum of all percentages must be exactly 100%. Recipients not included in the map receive nothing.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::set_budget_allocation.